"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEventMatchStoryActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
const awsLambdaUtils_1 = require("../../../../../awsLambdaUtils");
const getProcessMatchStory = (qpqConfig) => {
    const routes = quidproquo_webserver_1.qpqWebServerUtils.getAllRoutes(qpqConfig);
    return ({ qpqEventRecord }) => __awaiter(void 0, void 0, void 0, function* () {
        // Sort the routes by string length
        // Note: We may need to filter variable routes out {} as the variables are length independent
        const routesWithNoOptions = routes.filter((r) => r.method === qpqEventRecord.method || qpqEventRecord.method === 'OPTIONS' || (qpqEventRecord.method === 'HEAD' && r.method === 'GET'));
        // Find the most relevant match
        const sortedRoutes = quidproquo_webserver_1.qpqWebServerUtils.sortPathMatchConfigs(routesWithNoOptions);
        const matchedRoute = sortedRoutes
            .map((r) => ({
            match: (0, awsLambdaUtils_1.matchUrl)(r.path, qpqEventRecord.path),
            route: r,
        }))
            .find((m) => m.match.didMatch);
        if (!matchedRoute) {
            return (0, quidproquo_core_1.actionResultError)(quidproquo_core_1.ErrorTypeEnum.NotFound, `route not found [${qpqEventRecord.path}] - [${quidproquo_webserver_1.qpqWebServerUtils.getHeaderValue('user-agent', qpqEventRecord.headers)}]`);
        }
        const matchResult = {
            runtime: matchedRoute.route.runtime,
            runtimeOptions: matchedRoute.match.params || {},
            // TODO: Make this aware of the API that we are eventing
            config: quidproquo_webserver_1.qpqWebServerUtils.mergeAllRouteOptions('api', matchedRoute.route, qpqConfig),
        };
        return (0, quidproquo_core_1.actionResult)(matchResult);
    });
};
const getEventMatchStoryActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_core_1.EventActionType.MatchStory]: getProcessMatchStory(qpqConfig),
    });
});
exports.getEventMatchStoryActionProcessor = getEventMatchStoryActionProcessor;
