"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEventTransformResponseResultActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const quidproquo_webserver_1 = require("quidproquo-webserver");
const ErrorTypeHttpResponseMap = {
    [quidproquo_core_1.ErrorTypeEnum.BadRequest]: 400,
    [quidproquo_core_1.ErrorTypeEnum.Unauthorized]: 401,
    [quidproquo_core_1.ErrorTypeEnum.PaymentRequired]: 402,
    [quidproquo_core_1.ErrorTypeEnum.Forbidden]: 403,
    [quidproquo_core_1.ErrorTypeEnum.NotFound]: 404,
    [quidproquo_core_1.ErrorTypeEnum.TimeOut]: 408,
    [quidproquo_core_1.ErrorTypeEnum.Conflict]: 409,
    [quidproquo_core_1.ErrorTypeEnum.UnsupportedMediaType]: 415,
    [quidproquo_core_1.ErrorTypeEnum.OutOfResources]: 500,
    [quidproquo_core_1.ErrorTypeEnum.GenericError]: 500,
    [quidproquo_core_1.ErrorTypeEnum.NotImplemented]: 501,
    [quidproquo_core_1.ErrorTypeEnum.NoContent]: 204,
    [quidproquo_core_1.ErrorTypeEnum.Invalid]: 422,
};
const transformHttpEventHeadersToAPIGatewayProxyResultHeaders = (headers) => {
    return Object.keys(headers)
        .filter((header) => !!headers[header])
        .reduce((acc, header) => (Object.assign(Object.assign({}, acc), { [header]: headers[header] })), {});
};
const getResponseFromErrorResult = (error) => {
    const statusCode = ErrorTypeHttpResponseMap[error.errorType] || 500;
    return quidproquo_webserver_1.qpqWebServerUtils.toJsonEventResponse({
        errorType: error.errorType,
        errorText: error.errorText,
    }, statusCode);
};
const getProcessTransformResponseResult = (qpqConfig) => {
    // We might need to JSON.stringify the body.
    return ({ eventParams, qpqEventRecordResponses }) => __awaiter(void 0, void 0, void 0, function* () {
        const [apiGatewayEvent] = eventParams;
        const [record] = qpqEventRecordResponses;
        // If we have an error, we need to transform it to a response, otherwise we can just use the record as is
        let successRecord = record.success ? record.result : getResponseFromErrorResult(record.error);
        // Return an error if the body is the wrong type.
        if (successRecord.body && typeof successRecord.body !== 'string') {
            successRecord = getResponseFromErrorResult({
                errorText: 'Response body must be a string',
                errorType: quidproquo_core_1.ErrorTypeEnum.GenericError,
            });
        }
        // Add the cors headers
        const currentHeaders = successRecord.headers || {};
        const headers = Object.assign(Object.assign({}, quidproquo_webserver_1.qpqWebServerUtils.getCorsHeaders(qpqConfig, {}, apiGatewayEvent.headers)), currentHeaders);
        // Transform back to api gateway
        return (0, quidproquo_core_1.actionResult)({
            statusCode: successRecord.status,
            body: apiGatewayEvent.httpMethod === 'HEAD' || !successRecord.body ? '' : successRecord.body,
            isBase64Encoded: successRecord.isBase64Encoded,
            headers: transformHttpEventHeadersToAPIGatewayProxyResultHeaders(headers),
        });
    });
};
const getEventTransformResponseResultActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_core_1.EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
    });
});
exports.getEventTransformResponseResultActionProcessor = getEventTransformResponseResultActionProcessor;
