"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEventGetRecordsActionProcessor = void 0;
const quidproquo_core_1 = require("quidproquo-core");
function isCloudWatchAlarmNotification(obj) {
    return typeof obj === 'object' && !!obj.AlarmName && !!obj.Trigger;
}
function isErrorsCloudWatchAlarmNotification(cwn) {
    return cwn.Trigger.MetricName === 'Errors' && cwn.Trigger.Namespace === 'AWS/Lambda';
}
function isTimeoutCloudWatchAlarmNotification(cwn) {
    return cwn.Trigger.MetricName === 'Timeout' && cwn.Trigger.Namespace === 'AWS/Lambda';
}
function isThrottlesCloudWatchAlarmNotification(cwn) {
    return cwn.Trigger.MetricName === 'Throttles' && cwn.Trigger.Namespace === 'AWS/Lambda';
}
function buildQueueBaseEvent(messageId, notifyErrorQueueEvents, cloudWatchAlarmNotification) {
    const payload = {
        newStateReason: cloudWatchAlarmNotification.NewStateReason,
        newStateInAlarm: cloudWatchAlarmNotification.NewStateValue === 'ALARM',
        oldStateInAlarm: cloudWatchAlarmNotification.OldStateValue === 'ALARM',
    };
    const queueEvent = {
        id: messageId,
        message: {
            type: notifyErrorQueueEvents,
            payload,
        },
    };
    return queueEvent;
}
const getProcessGetRecords = (qpqConfig) => {
    return ({ eventParams: [sqsEvent, context] }) => __awaiter(void 0, void 0, void 0, function* () {
        const records = sqsEvent.Records.map((record) => {
            const parsedInternalEventRecord = JSON.parse(record.body);
            if (isCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                // Error
                if (isErrorsCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                    const queueEvent = buildQueueBaseEvent(record.messageId, quidproquo_core_1.NotifyErrorQueueEvents.Error, parsedInternalEventRecord);
                    return queueEvent;
                }
                // Timeout
                else if (isTimeoutCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                    const queueEvent = buildQueueBaseEvent(record.messageId, quidproquo_core_1.NotifyErrorQueueEvents.Timeout, parsedInternalEventRecord);
                    return queueEvent;
                }
                // Throttle
                else if (isThrottlesCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                    const queueEvent = buildQueueBaseEvent(record.messageId, quidproquo_core_1.NotifyErrorQueueEvents.Throttle, parsedInternalEventRecord);
                    return queueEvent;
                }
                const queueEvent = buildQueueBaseEvent(record.messageId, quidproquo_core_1.NotifyErrorQueueEvents.Unknown, parsedInternalEventRecord);
                return queueEvent;
            }
            // TODO: Remove the session from this object
            //       note: we still need to access the session in the story execution for depth and auth etc.
            const internalEventRecord = {
                message: {
                    type: parsedInternalEventRecord.type,
                    payload: parsedInternalEventRecord.payload,
                },
                id: record.messageId,
            };
            return internalEventRecord;
        });
        return (0, quidproquo_core_1.actionResult)(records);
    });
};
const getEventGetRecordsActionProcessor = (qpqConfig) => __awaiter(void 0, void 0, void 0, function* () {
    return ({
        [quidproquo_core_1.EventActionType.GetRecords]: getProcessGetRecords(qpqConfig),
    });
});
exports.getEventGetRecordsActionProcessor = getEventGetRecordsActionProcessor;
