"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.askRunNeptuneOpenCypherQuery = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const customActions_1 = require("../customActions");
const askConvertNeptuneCypherResponseToCypherResponse_1 = require("./converters/askConvertNeptuneCypherResponseToCypherResponse");
const utils_1 = require("./utils");
function* askRunNeptuneOpenCypherQuery({ graphDatabaseName, openCypherQuery, params, instance, }) {
    const graphEndpoints = yield* (0, customActions_1.askGraphDatabaseForNeptuneGetEndpoints)(graphDatabaseName);
    const graphEndpoint = instance === quidproquo_core_1.GraphDatabaseInstanceType.Read ? graphEndpoints.readEndpoint : graphEndpoints.writeEndpoint;
    if (!graphEndpoint) {
        return yield* (0, quidproquo_core_1.askThrowError)(quidproquo_core_1.ErrorTypeEnum.GenericError, `No [${instance}] endpoint found`);
    }
    const neptuneQuery = (0, utils_1.convertQpqQueryToNeptune)(openCypherQuery);
    const response = yield* (0, quidproquo_core_1.askNetworkRequest)('POST', `${graphEndpoint}/openCypher`, {
        body: { query: neptuneQuery, parameters: params },
        headers: {
            'Content-Type': 'application/json',
            Accept: 'application/json',
        },
    });
    if (response.status < 200 || response.status >= 300) {
        return yield* (0, quidproquo_core_1.askThrowError)(quidproquo_core_1.ErrorTypeEnum.GenericError, 'Unable to query database');
    }
    return yield* (0, askConvertNeptuneCypherResponseToCypherResponse_1.askConvertNeptuneCypherResponseToCypherResponse)(response.data);
}
exports.askRunNeptuneOpenCypherQuery = askRunNeptuneOpenCypherQuery;
