"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.memoFuncAsync = void 0;
const node_cache_1 = __importDefault(require("node-cache"));
const cache = new WeakMap();
/**
 * Memoizes a function by caching its return values.
 * @param func The function to memoize.
 * @param ttlInSeconds Time-to-live for the cached values in seconds.
 * @returns The memoized function.
 */
const memoFuncAsync = (func, ttlInSeconds = 3600) => {
    return ((...args) => __awaiter(void 0, void 0, void 0, function* () {
        if (!cache.has(func)) {
            cache.set(func, new node_cache_1.default({ stdTTL: ttlInSeconds }));
        }
        const cacheKey = JSON.stringify(args);
        const nodeCache = cache.get(func);
        if (nodeCache.has(cacheKey)) {
            return nodeCache.get(cacheKey);
        }
        // Await the result
        const result = yield func(...args);
        // and then cache it
        nodeCache.set(cacheKey, result);
        return result;
    }));
};
exports.memoFuncAsync = memoFuncAsync;
