"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decodeValidJwt = void 0;
const jsonwebtoken_1 = require("jsonwebtoken");
const jwks_rsa_1 = __importDefault(require("jwks-rsa"));
const decodeValidJwt = (userPoolId, region, ignoreExpiration, accessToken) => __awaiter(void 0, void 0, void 0, function* () {
    if (!accessToken) {
        return null;
    }
    try {
        const decodedToken = (0, jsonwebtoken_1.decode)(accessToken, { complete: true });
        if (!decodedToken) {
            return null;
        }
        const client = (0, jwks_rsa_1.default)({
            jwksUri: `https://cognito-idp.${region}.amazonaws.com/${userPoolId}/.well-known/jwks.json`,
        });
        const key = yield client.getSigningKey(decodedToken.header.kid);
        const signingKey = key.getPublicKey();
        const payload = (0, jsonwebtoken_1.verify)(accessToken, signingKey, {
            algorithms: ['RS256'],
            ignoreExpiration,
        });
        const decodedAccessToken = {
            userId: payload.sub,
            username: payload.username,
            exp: payload.exp,
            wasValid: true,
        };
        return decodedAccessToken;
    }
    catch (e) {
        console.log('Failed to decode jwt token', e);
        return null;
    }
});
exports.decodeValidJwt = decodeValidJwt;
