"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUser = void 0;
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const createAwsClient_1 = require("../createAwsClient");
const getUserAttribute = (attributeName, userAttributes) => {
    const lowerAttributeName = attributeName.toLowerCase();
    const attribute = userAttributes.find((k) => { var _a; return ((_a = k.Name) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === lowerAttributeName; });
    return attribute === null || attribute === void 0 ? void 0 : attribute.Value;
};
const getUser = (accessToken, region) => __awaiter(void 0, void 0, void 0, function* () {
    const cognitoClient = (0, createAwsClient_1.createAwsClient)(client_cognito_identity_provider_1.CognitoIdentityProviderClient, {
        region,
    });
    const params = {
        AccessToken: accessToken,
    };
    const response = yield cognitoClient.send(new client_cognito_identity_provider_1.GetUserCommand(params));
    const attributeTypes = (response.UserAttributes || []).filter((ua) => !!ua.Value);
    const userAttributes = attributeTypes.reduce((acc, ua) => (Object.assign(Object.assign({}, acc), { [ua.Name]: ua.Value })), {});
    const user = {
        username: response.Username,
        id: getUserAttribute('sub', attributeTypes),
        email: getUserAttribute('email', attributeTypes),
        userAttributes,
    };
    return user;
});
exports.getUser = getUser;
