"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.respondToAuthChallengeChallenge = void 0;
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const createAwsClient_1 = require("../createAwsClient");
const calculateSecretHash_1 = require("./utils/calculateSecretHash");
const transformCognitoResponse_1 = require("./utils/transformCognitoResponse");
const getUserPoolClientSecret_1 = require("./getUserPoolClientSecret");
const respondToAuthChallengeChallenge = (userPoolId, clientId, region, username, session, challengeNameType, attributes) => __awaiter(void 0, void 0, void 0, function* () {
    const cognitoClient = (0, createAwsClient_1.createAwsClient)(client_cognito_identity_provider_1.CognitoIdentityProviderClient, {
        region,
    });
    const clientSecret = yield (0, getUserPoolClientSecret_1.getUserPoolClientSecret)(userPoolId, clientId, region);
    const secretHash = (0, calculateSecretHash_1.calculateSecretHash)(username, clientId, clientSecret);
    const params = {
        ChallengeName: challengeNameType,
        ClientId: clientId,
        Session: session,
        ChallengeResponses: Object.assign({ USERNAME: username, SECRET_HASH: secretHash }, attributes),
    };
    const issueDateTime = new Date().toISOString();
    const response = yield cognitoClient.send(new client_cognito_identity_provider_1.RespondToAuthChallengeCommand(params));
    // transform the response into your custom format, similar to your refreshToken function
    return (0, transformCognitoResponse_1.cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo)(response, issueDateTime);
});
exports.respondToAuthChallengeChallenge = respondToAuthChallengeChallenge;
