"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo = exports.cognitoChallengeNameTypeToQpqAuthenticateUserChallenge = exports.cognitoAuthenticationResultTypeToQpqAuthenticationInfo = void 0;
const quidproquo_core_1 = require("quidproquo-core");
const client_cognito_identity_provider_1 = require("@aws-sdk/client-cognito-identity-provider");
const cognitoAuthenticationResultTypeToQpqAuthenticationInfo = (authResult, issueDateTime) => {
    // Parse the issueDateTime and add the expiresIn to get the expiration date
    let issueDate = new Date(issueDateTime);
    issueDate.setSeconds(issueDate.getSeconds() + (authResult.ExpiresIn || 0));
    const expiresAt = issueDate.toISOString();
    return {
        accessToken: authResult.AccessToken,
        idToken: authResult.IdToken,
        refreshToken: authResult.RefreshToken,
        tokenType: authResult.TokenType,
        expirationDurationInSeconds: authResult.ExpiresIn,
        expiresAt,
    };
};
exports.cognitoAuthenticationResultTypeToQpqAuthenticationInfo = cognitoAuthenticationResultTypeToQpqAuthenticationInfo;
const cognitoChallengeNameTypeToQpqAuthenticateUserChallenge = (cognitoChallengeName) => {
    if (!cognitoChallengeName) {
        return quidproquo_core_1.AuthenticateUserChallenge.NONE;
    }
    const map = {
        [client_cognito_identity_provider_1.ChallengeNameType.NEW_PASSWORD_REQUIRED]: quidproquo_core_1.AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED,
        [client_cognito_identity_provider_1.ChallengeNameType.CUSTOM_CHALLENGE]: quidproquo_core_1.AuthenticateUserChallenge.CUSTOM_CHALLENGE,
    };
    // TODO: handle the NOT-IMP cases
    const challenge = map[cognitoChallengeName] || `QPQ-NOT-IMP-${cognitoChallengeName}`;
    return challenge;
};
exports.cognitoChallengeNameTypeToQpqAuthenticateUserChallenge = cognitoChallengeNameTypeToQpqAuthenticateUserChallenge;
const cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo = (authResponse, issueDateTime) => {
    const res = {
        session: authResponse.Session,
        challenge: (0, exports.cognitoChallengeNameTypeToQpqAuthenticateUserChallenge)(authResponse.ChallengeName),
        challengeParameters: authResponse.ChallengeParameters,
    };
    if (authResponse.AuthenticationResult) {
        res.authenticationInfo = (0, exports.cognitoAuthenticationResultTypeToQpqAuthenticationInfo)(authResponse.AuthenticationResult, issueDateTime);
    }
    return res;
};
exports.cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo = cognitoAdminInitiateAuthResponseToQpqAuthenticationInfo;
