"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAwsClient = void 0;
const cache = new WeakMap();
function createAwsClient(ClientClass, args) {
    // Get or create the Map for the ClientClass
    let argsCache = cache.get(ClientClass);
    if (!argsCache) {
        argsCache = new Map();
        cache.set(ClientClass, argsCache);
    }
    // Generate a key for the arguments
    const argsKey = JSON.stringify(args);
    // Check if the instance already exists in the cache
    if (!argsCache.has(argsKey)) {
        const newClient = new ClientClass(args);
        // If the send method exists, wrap it with error handling so we can see it in the logs
        if (typeof newClient.send === 'function') {
            const originalSend = newClient.send;
            newClient.send = function (...sendArgs) {
                return __awaiter(this, void 0, void 0, function* () {
                    try {
                        return yield originalSend.apply(this, sendArgs);
                    }
                    catch (error) {
                        console.log(ClientClass.name || 'aws client', args, 'send args', sendArgs, 'error', error.message);
                        throw error;
                    }
                });
            };
        }
        // Create a new instance and store it in the cache
        argsCache.set(argsKey, newClient);
    }
    // Return the cached instance
    return argsCache.get(argsKey);
}
exports.createAwsClient = createAwsClient;
