"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNeptuneEndpoints = void 0;
const client_neptune_1 = require("@aws-sdk/client-neptune");
const createAwsClient_1 = require("../createAwsClient");
const getNeptuneEndpoints = (clusterIdentifier, region) => __awaiter(void 0, void 0, void 0, function* () {
    const neptuneClient = (0, createAwsClient_1.createAwsClient)(client_neptune_1.NeptuneClient, { region });
    const command = new client_neptune_1.DescribeDBClustersCommand({
        DBClusterIdentifier: clusterIdentifier,
    });
    try {
        const response = yield neptuneClient.send(command);
        if (response.DBClusters && response.DBClusters.length > 0) {
            const cluster = response.DBClusters[0];
            const writeEndpoint = cluster.Endpoint && cluster.Port ? `https://${cluster.Endpoint}:${cluster.Port}` : undefined;
            const readEndpoint = cluster.ReaderEndpoint && cluster.Port ? `https://${cluster.ReaderEndpoint}:${cluster.Port}` : undefined;
            return { writeEndpoint, readEndpoint };
        }
        return {};
    }
    catch (error) {
        console.error('Error fetching Neptune cluster endpoints:', error);
        throw new Error(`Failed to retrieve Neptune endpoints: ${error}`);
    }
});
exports.getNeptuneEndpoints = getNeptuneEndpoints;
