import { actionResult, actionResultError, EventActionType, } from 'quidproquo-core';
const getProcessTransformResponseResult = (qpqConfig) => {
    // We might need to JSON.stringify the body.
    return async ({ eventParams, qpqEventRecordResponses }) => {
        const [customMessageTriggerEvent] = eventParams;
        const [qpqEventRecordResponse] = qpqEventRecordResponses;
        // If the runtime failed for some reason, just return this out as a fail
        if (!qpqEventRecordResponse.success) {
            return actionResultError(qpqEventRecordResponse.error.errorType, qpqEventRecordResponse.error.errorText, qpqEventRecordResponse.error.errorStack);
        }
        // No error has happened
        let successRecord = qpqEventRecordResponse.result;
        const eventOutput = {
            ...customMessageTriggerEvent,
            response: {
                ...customMessageTriggerEvent.response,
            },
        };
        // challengeMetadata / publicChallengeParameters / challengeMetadata can all be null.
        if (successRecord.challengeName) {
            eventOutput.response.challengeMetadata = successRecord.challengeName;
        }
        if (successRecord.privateChallengeParameters) {
            eventOutput.response.privateChallengeParameters = successRecord.privateChallengeParameters;
        }
        if (successRecord.publicChallengeParameters) {
            eventOutput.response.publicChallengeParameters = successRecord.publicChallengeParameters;
        }
        return actionResult(eventOutput);
    };
};
export const getEventTransformResponseResultActionProcessor = async (qpqConfig) => ({
    [EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
});
