import { actionResult, EventActionType, NotifyErrorQueueEvents, } from 'quidproquo-core';
function isCloudWatchAlarmNotification(obj) {
    return typeof obj === 'object' && !!obj.AlarmName && !!obj.Trigger;
}
function isErrorsCloudWatchAlarmNotification(cwn) {
    return cwn.Trigger.MetricName === 'Errors' && cwn.Trigger.Namespace === 'AWS/Lambda';
}
function isTimeoutCloudWatchAlarmNotification(cwn) {
    return cwn.Trigger.MetricName === 'Timeout' && cwn.Trigger.Namespace === 'AWS/Lambda';
}
function isThrottlesCloudWatchAlarmNotification(cwn) {
    return cwn.Trigger.MetricName === 'Throttles' && cwn.Trigger.Namespace === 'AWS/Lambda';
}
function buildQueueBaseEvent(messageId, notifyErrorQueueEvents, cloudWatchAlarmNotification) {
    const payload = {
        newStateReason: cloudWatchAlarmNotification.NewStateReason,
        newStateInAlarm: cloudWatchAlarmNotification.NewStateValue === 'ALARM',
        oldStateInAlarm: cloudWatchAlarmNotification.OldStateValue === 'ALARM',
    };
    const queueEvent = {
        id: messageId,
        message: {
            type: notifyErrorQueueEvents,
            payload,
        },
    };
    return queueEvent;
}
const getProcessGetRecords = (qpqConfig) => {
    return async ({ eventParams: [sqsEvent, context] }) => {
        const records = sqsEvent.Records.map((record) => {
            const parsedInternalEventRecord = JSON.parse(record.body);
            if (isCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                // Error
                if (isErrorsCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                    const queueEvent = buildQueueBaseEvent(record.messageId, NotifyErrorQueueEvents.Error, parsedInternalEventRecord);
                    return queueEvent;
                }
                // Timeout
                else if (isTimeoutCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                    const queueEvent = buildQueueBaseEvent(record.messageId, NotifyErrorQueueEvents.Timeout, parsedInternalEventRecord);
                    return queueEvent;
                }
                // Throttle
                else if (isThrottlesCloudWatchAlarmNotification(parsedInternalEventRecord)) {
                    const queueEvent = buildQueueBaseEvent(record.messageId, NotifyErrorQueueEvents.Throttle, parsedInternalEventRecord);
                    return queueEvent;
                }
                const queueEvent = buildQueueBaseEvent(record.messageId, NotifyErrorQueueEvents.Unknown, parsedInternalEventRecord);
                return queueEvent;
            }
            // TODO: Remove the session from this object
            //       note: we still need to access the session in the story execution for depth and auth etc.
            const internalEventRecord = {
                message: {
                    type: parsedInternalEventRecord.type,
                    payload: parsedInternalEventRecord.payload,
                },
                id: record.messageId,
            };
            return internalEventRecord;
        });
        return actionResult(records);
    };
};
export const getEventGetRecordsActionProcessor = async (qpqConfig) => ({
    [EventActionType.GetRecords]: getProcessGetRecords(qpqConfig),
});
