import { qpqConfigAwsUtils } from 'quidproquo-config-aws';
import { actionResult, actionResultError, ErrorTypeEnum, EventBusActionType, qpqCoreUtils, } from 'quidproquo-core';
import { getEventBusSnsTopicArn } from '../../../awsNamingUtils';
import { publishMessage } from '../../../logic/sns/publishMessage';
const getProcessEventBusSendMessage = (qpqConfig) => {
    return async ({ eventBusName, eventBusMessages, context, }, session) => {
        const region = qpqConfigAwsUtils.getApplicationModuleDeployRegion(qpqConfig);
        const eventBusConfig = qpqCoreUtils.getEventBusConfigByName(eventBusName, qpqConfig);
        if (!eventBusConfig) {
            return actionResultError(ErrorTypeEnum.NotFound, `Event bus ${eventBusName} not found`);
        }
        const topicArn = getEventBusSnsTopicArn(eventBusConfig.owner?.resourceNameOverride || eventBusName, qpqConfig, eventBusConfig.owner?.module || qpqCoreUtils.getApplicationModuleName(qpqConfig), eventBusConfig.owner?.environment || qpqCoreUtils.getApplicationModuleEnvironment(qpqConfig), eventBusConfig.owner?.application || qpqCoreUtils.getApplicationName(qpqConfig), eventBusConfig.owner?.feature || qpqCoreUtils.getApplicationModuleFeature(qpqConfig));
        await publishMessage(topicArn, region, eventBusMessages.map((message) => {
            const eventBusMessageWithSession = {
                ...message,
                storySession: {
                    ...session,
                    context,
                },
            };
            return JSON.stringify(eventBusMessageWithSession);
        }));
        return actionResult(void 0);
    };
};
export const getEventBusSendMessagesActionProcessor = async (qpqConfig) => ({
    [EventBusActionType.SendMessages]: getProcessEventBusSendMessage(qpqConfig),
});
