import { qpqConfigAwsUtils } from 'quidproquo-config-aws';
import { actionResult, actionResultError, qpqCoreUtils, } from 'quidproquo-core';
import { ServiceFunctionActionType } from 'quidproquo-webserver';
import { getConfigRuntimeResourceName } from '../../../awsNamingUtils';
import { executeLambdaByName } from '../../../logic/lambda/executeLambdaByName';
const getProcessExecute = (qpqConfig) => {
    return async ({ functionName, service, payload, context, isAsync }, session) => {
        const region = qpqConfigAwsUtils.getApplicationModuleDeployRegion(qpqConfig);
        const appName = qpqCoreUtils.getApplicationName(qpqConfig);
        const environment = qpqCoreUtils.getApplicationModuleEnvironment(qpqConfig);
        const feature = qpqCoreUtils.getApplicationModuleFeature(qpqConfig);
        const awsFunctionName = getConfigRuntimeResourceName(`${functionName}-sfunc`, appName, service, environment, feature);
        const serviceFunctionEvent = {
            functionName: functionName,
            payload: payload,
            storySession: {
                ...session,
                context,
            },
        };
        const result = await executeLambdaByName(awsFunctionName, region, serviceFunctionEvent, isAsync);
        if (!result) {
            return actionResult(void 0);
        }
        if (!result.success) {
            return actionResultError(result.error.errorType, result.error.errorText, `${service}::${functionName}: ${result?.error.errorStack || ''}`);
        }
        return actionResult(result.result);
    };
};
export const getServiceFunctionExecuteActionProcessor = async (qpqConfig) => ({
    [ServiceFunctionActionType.Execute]: getProcessExecute(qpqConfig),
});
