import { CognitoIdentityProviderClient, GetUserCommand } from '@aws-sdk/client-cognito-identity-provider';
import { createAwsClient } from '../createAwsClient';
const getUserAttribute = (attributeName, userAttributes) => {
    const lowerAttributeName = attributeName.toLowerCase();
    const attribute = userAttributes.find((k) => k.Name?.toLowerCase() === lowerAttributeName);
    return attribute?.Value;
};
export const getUser = async (accessToken, region) => {
    const cognitoClient = createAwsClient(CognitoIdentityProviderClient, {
        region,
    });
    const params = {
        AccessToken: accessToken,
    };
    const response = await cognitoClient.send(new GetUserCommand(params));
    const attributeTypes = (response.UserAttributes || []).filter((ua) => !!ua.Value);
    const userAttributes = attributeTypes.reduce((acc, ua) => ({ ...acc, [ua.Name]: ua.Value }), {});
    const user = {
        username: response.Username,
        id: getUserAttribute('sub', attributeTypes),
        email: getUserAttribute('email', attributeTypes),
        userAttributes,
    };
    return user;
};
