import { DynamoDBClient, ScanCommand } from '@aws-sdk/client-dynamodb';
import { createAwsClient } from '../createAwsClient';
export async function getAllItems(tableName, region) {
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    let records = [];
    let lastEvaluatedKey;
    do {
        const scanParams = {
            TableName: tableName,
            ExclusiveStartKey: lastEvaluatedKey,
        };
        try {
            const result = await dynamoDBClient.send(new ScanCommand(scanParams));
            records = records.concat(result.Items);
            lastEvaluatedKey = result.LastEvaluatedKey;
        }
        catch (error) {
            console.error('Error scanning DynamoDB table:', error);
            throw error;
        }
    } while (lastEvaluatedKey);
    return records;
}
