import { DynamoDBClient, QueryCommand } from '@aws-sdk/client-dynamodb';
import { createAwsClient } from '../createAwsClient';
import { lastEvaluatedKeyToString, stringToLastEvaluatedKey } from './logs';
export async function getLogChildrenByFromCorrelation(tableName, region, fromCorrelation, pageKey) {
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const queryParams = {
        TableName: tableName,
        // removed IndexName
        KeyConditionExpression: '#fromCorrelation = :fromCorrelation',
        ExpressionAttributeNames: {
            '#fromCorrelation': 'fromCorrelation', // define attribute name
        },
        ExpressionAttributeValues: {
            ':fromCorrelation': { S: fromCorrelation },
        },
    };
    if (pageKey) {
        queryParams.ExclusiveStartKey = stringToLastEvaluatedKey(pageKey);
    }
    try {
        const queryResult = await dynamoDBClient.send(new QueryCommand(queryParams));
        const items = (queryResult.Items || []).map((i) => {
            const [startedAt, correlation] = i.startedAtWithCorrelation.S?.split('#') || [];
            const metaData = {
                generic: i.generic.S || '',
                runtimeType: i.runtimeType.S,
                error: i.error?.S,
                startedAt: startedAt,
                correlation,
                moduleName: i.moduleName.S || '',
                fromCorrelation: i.fromCorrelation?.S,
                executionTimeMs: i.executionTimeMs?.N ? parseInt(i.executionTimeMs.N) : 0,
            };
            return metaData;
        });
        if (queryResult.LastEvaluatedKey) {
            const nextPageKey = lastEvaluatedKeyToString(queryResult.LastEvaluatedKey);
            // You can return the nextPageKey along with the items, so it can be used for the next query.
            return { items, nextPageKey };
        }
        else {
            return { items };
        }
    }
    catch (err) {
        console.error(`Failed to query items with the specified fromCorrelation: ${err}`);
        throw err;
    }
}
