import { DynamoDBClient, QueryCommand } from '@aws-sdk/client-dynamodb';
import { createAwsClient } from '../createAwsClient';
import { itemsToQpqPagedData } from './utils/itemsToQpqPagedData';
import { convertDynamoMapToObject } from './convertObjectToDynamoMap';
import { stringToLastEvaluatedKey } from './logs';
import { buildDynamoQueryExpression, buildExpressionAttributeNames, buildExpressionAttributeValues } from './qpqDynamoOrm';
export async function query(tableName, region, keyExpression, filterExpression, pageKey, indexName, limit, sortAscending) {
    // Instantiate DynamoDB client
    const dynamoDBClient = createAwsClient(DynamoDBClient, { region });
    const params = {
        TableName: tableName,
        KeyConditionExpression: buildDynamoQueryExpression(keyExpression),
        FilterExpression: filterExpression && buildDynamoQueryExpression(filterExpression),
        ExpressionAttributeValues: buildExpressionAttributeValues([keyExpression, filterExpression]),
        ExpressionAttributeNames: buildExpressionAttributeNames([keyExpression, filterExpression]),
        IndexName: indexName,
        Limit: limit,
        ScanIndexForward: sortAscending,
    };
    if (pageKey) {
        params.ExclusiveStartKey = stringToLastEvaluatedKey(pageKey);
    }
    // Create QueryCommand
    const command = new QueryCommand(params);
    // TODO: Catch errors and throw QPQ ones
    const data = await dynamoDBClient.send(command);
    return itemsToQpqPagedData((data.Items?.map((i) => convertDynamoMapToObject(i)) || []), data.LastEvaluatedKey);
}
